/*
 *  Eukleides version 1.5.4
 *  Copyright (c) Christian Obrecht 2004-2010
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

void create_circle_with_radius(_param p);

void circle_center(_param p);

void create_circle_with_diameter(_param p);

void create_circumcircle(_param p);

void create_incircle(_param p);

void translate_circle(_param p);

void reflect_circle(_param p);

void symetric_circle(_param p);

void rotate_circle(_param p);

void homothetic_circle(_param p);

void circle_radius(_param p);

void circle_perimeter(_param p);

void circle_area(_param p);

void point_on_circle_argument(_param p);
